@@ -1,4 +1,4 @@
 inline int DateTime::displayZoneShift() const
 {
-    return d_displayZoneShift;
+    return d_zone / 60;
 }
