@@ -1,4 +1,4 @@
 inline bool operator==(DateTime const &left, DateTime const &right)
 {
-    return left.d_utcSec == right.d_utcSec;
-}   
+    return left.d_time == right.d_time;
+}
