@@ -1,4 +1,2 @@
 inline void DateTime::setValid()
-{
-    d_ok = true;
-}
+{}
