@@ -2,9 +2,7 @@
 
 bool DateTime::setWeekday(Weekday weekday, Relative where)
 {
-    TimeStruct ts = d_tm;
-
-    int difference = static_cast<int>(weekday) - ts.tm_wday;
+    int difference = static_cast<int>(weekday) - d_tm.tm_wday;
 
     switch (where)
     {
@@ -20,14 +18,8 @@ bool DateTime::setWeekday(Weekday weekday, Relative where)
         break;
 
         default:
-        throw Exception{1} << 
+        throw Exception{ 1 } <<
                             "DateTime::setWeekday(): invalid Relative spec.";
     }
-
-    ts.tm_mday += difference;
-    
-    return updateTime(ts);
+    return setDay(d_tm.tm_mday + difference);
 }
-
-
-
