@@ -1,4 +1,4 @@
 inline time_t DateTime::time() const
 {
-    return d_utcSec;
+    return d_time;
 }
