@@ -1,14 +1,14 @@
 #include "digestbuf.ih"
 
-int DigestBuf::overflow(int c)
+int DigestBuf::overflow(int ch)
 {
     EVP_DigestUpdate(d_pimpl->ctx, d_pimpl->buffer, d_pimpl->bufsize);
     setp(d_pimpl->buffer, d_pimpl->buffer + d_pimpl->bufsize);
 
-    if (c != EOF)
+    if (ch != EOF)
     {
-        *pptr() = static_cast<char>(c);         
+        *pptr() = ch;
         pbump(1);
     }
-    return c;
+    return ch;
 }
