@@ -9,12 +9,15 @@ std::ostream &operator<<(std::ostream &str, LogManipulator manipulator)
     {
         case FATAL:
             str.flush();
-        throw Errno(1);                     // was: exit(1) :-(
+        throw Exception(1);
 
         case nl:
             str << static_cast<char>(0);    // 0-char is interpreted by
                                             // LogBuffer as '\n', without
         break;                              // timestamp writing request.
+
+        default:                            // fnl not used. This 
+        break;                              // prevents the 'not used' warning
     }
     return str;
 }
