@@ -2,26 +2,28 @@
 
 int LogBuffer::overflow(int c)
 {
-    if (!d_active)          // ignore the char if we're not active.
-        return c;
-
-    if (c == 0)             // newline without timestamp request
-        d_empty = false;
-
-    if (d_timestamps != NOTIMESTAMPS)  // timestamps requested
-    {
-        if (d_empty)        // write one if there's nothing on the line
+    if (c != 1 and not d_active)    // ignore the char if we're not active.
+    {                               // and if the ch. is not fnl (forced \n)
+        if (c == '\n')
         {
-            insertTimestamp();
-            d_empty = false;
+            d_empty = true;
+            d_active = true;
         }
+        return c;
     }
+
     switch (c)
     {
         case 0:             // write newline, without considering d_empty true
+            d_empty = false;
             c = '\n';       // also see logbuffer/operatorinsert.cc
         break;
 
+        case 1:             // at fnl (forced new line) (re)activate and
+            d_active = true;    // fallthrough (continue) as \n
+            c = '\n';
+        [[fallthrough]];
+
         case '\n':          // at '\n', set d_empty to true. This generates 
                             // a timestamp at the next insertion
             d_empty = true;
