@@ -7,8 +7,8 @@ int MultiStreambuf::sync()
 
     Insert istruct = {d_buffer, true};
 
-    for_each(d_os.begin(), d_os.end(), 
-             FnWrap1c<stream &, Insert &>(&insert, istruct));
+    for (auto &os: d_os)
+        insertStruct(os, istruct);
 
     d_buffer.erase();
     return istruct.ok ? 0 : 1;
